bayespy.inference.vmp.nodes.deterministic.Deterministic.delete
==============================================================

.. currentmodule:: bayespy.inference.vmp.nodes.deterministic

.. automethod:: Deterministic.delete